@@ -1,9 +1,9 @@
 
 from .iterable import tally, counts, counts_by
-from .indexing import first, last, rotate_left, rotate_right
+from .indexing import first, last, rotate_left, rotate_right, partition
 from .numbertests import even_q, odd_q
 from .nesting import nest_while_list, nest_while, nest, nest_list
-
+from .classes import up_to
 
 
 #%%
